/*
 * Chapter 22
 *
 * Compares the voltage of the potentiometer on the PA1 (ADC1) pin
 * with the voltage of the voltage divider created by the NTC (AD conversion).
 * If the NTC voltage is greater than the measured voltage on the potentiometer,
 * the LED on the PA0 pin will light up. Otherwise, it will not light up.
 */

#include "../Headers/main.h"

volatile uint32_t cntr = 0;
volatile double U_potmeter = 0;
volatile double U_NTC = 0;

//Timer1 interrupt
ISR(TIMER1_OVF_vect)
{
    //The counter is increased, if it hasn't reached the maximum yet
    if (cntr < CNTR_MAX)
    {
        cntr++;
    }

    //If it has reached the maximum
    else
    {
        //Reset counter
		cntr = 0;
        //AD conversion is started (sampling)
        ADCStart();
    }
}

//AD conversion is completed, AD interrupt
ISR(ADC_vect)
{
    //Saves the measured voltage to the appropriate variable based on the AD channel
    switch (ADC_state)
    {
    case potmeter:
        U_potmeter = ADCH * ADC_CONST;
        break;

    case NTC:
        U_NTC = ADCH * ADC_CONST;
        break;

    default:
        break;
    }

    //Switching to the next ADC channel
    NextCH();
}

int main(void)
{
    IOInit();
    TimerInit();
    ADCInit();

    //Enabling the ADC
    ADCEnable();

    //Infinite loop
    while (1)
    {
        //If the voltage of the NTC divider is greater than the voltage of the potentiometer, then the LED is on
        if (U_NTC > U_potmeter)
        {
            sbi(PORTA, 0);
        }

        //Otherwise the LED is off
        else
        {
            cbi(PORTA, 0);
        }
    }

    return 0;
}