/*
 * Chapter 22
 *
 * The lower 8 bits of the AD value of the potentiometer on the PA1 pin (ADC1) are put
 * into the PWM register of the TMR2, which means the duty cycle of the PWM signal, which appears
 * on the PD7 pin, is adjustable by a potentiometer.
 */

#include "../Headers/main.h"

volatile uint32_t cntr = 0;
volatile enum
{
    fel, le
}
cntr_dir = fel;

//Timer1 interrupt
ISR(TIMER1_OVF_vect)
{
    //The timer is increased, if it hasn't reached the maximum yet
    if (cntr < CNTR_MAX)
    {
        //The counter is increased
        cntr++;
    }

    //If it has reached
    else
    {

        cntr = 0;
        //AD conversion is started (sampling)
        ADCStart();
    }
}

//AD conversion is completed, AD interrupt
ISR(ADC_vect)
{
    //Load the upper 8 bits of the AD result into the PWM timer register
    OCR2 = ADCH;
}

int main(void)
{
    IOInit();
    TimerInit();
    PWMInit();
    ADCInit();

    //Enabling the AD converter
    ADCEnable();
    //The duty cycle of the PWM should be 0 in the beginning
    OCR2 = 0;

    //Infinite loop
    while (1)
    {
        //PWM setting happens by interrupt
    }

    return 0;
}